﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using Telerik.Web.UI;
using Telerik.Web.UI.Calendar;
using System.Drawing;

public partial class RadSheduler : System.Web.UI.Page
{
	private const string ProviderSessionKey = "Telerik.Web.Examples.Scheduler.Outlook2007.DefaultCS";
	private Dictionary<int, string> checkBoxIDs;

	XmlSchedulerProvider Provider
	{
		get
		{
			XmlSchedulerProvider provider = (XmlSchedulerProvider)Session[ProviderSessionKey];
			if (Session[ProviderSessionKey] == null || !IsPostBack)
			{
				provider = new XmlSchedulerProvider(Server.MapPath("~/App_Data/Appointments_Outlook.xml"), false);
				Session[ProviderSessionKey] = provider;
			}

			return provider;
		}
	}

	protected void Page_Init(object sender, EventArgs e)
	{
		RadScheduler1.Provider = Provider;
	}

	private void Page_Load(object sender, EventArgs e)
	{
		checkBoxIDs = new Dictionary<int, string>();
		checkBoxIDs.Add(1, "chkDevelopment");
		checkBoxIDs.Add(2, "chkMarketing");
		checkBoxIDs.Add(3, "chkQ1");
		checkBoxIDs.Add(4, "chkQ2");

		if (!IsPostBack)
		{
			RadCalendar1.SelectedDate = RadScheduler1.SelectedDate;
			SyncCalendars();
		}

		testLoad();
	}

	protected void testLoad()
	{
		rpbMyCalendars.Items.Clear();
		createPanel(1, 8);
		createPanel(2, 8);
	}

	protected void createPanel(int panelNum, int count)
	{
		var rpiRoot = new RadPanelItem("Root Panel " + panelNum);
		rpbMyCalendars.Items.Add(rpiRoot);

		for (var i = 1; i < count; i++)
		{
			var rpiSub = new RadPanelItem("");
			rpiRoot.Items.Add(rpiSub);

			var literal = new Literal
			{
				Text = "<div title='Sub Panel " + i + "'>Sub Panel " + i + "</div>",
				ID = "tx_" + i,
			};
			rpiSub.Controls.Add(literal);

			var cp = new RadColorPicker
			{
				ID = "cp_" + i,
				ShowIcon = true,
				SelectedColor = Color.FromArgb(i * 0x100 + i * 0x10 + i),
				PaletteModes = PaletteModes.HSB,
				AutoPostBack = true,
				OnClientPopUpShow = "showColorPicker"
			};
			rpiSub.Controls.Add(cp);
		}
	}

	protected void RadScheduler1_NavigationComplete(object sender, SchedulerNavigationCompleteEventArgs e)
	{
		RadCalendar1.FocusedDate = RadScheduler1.SelectedDate;
		SyncCalendars();
	}

	protected void RadCalendar1_DefaultViewChanged(object sender, DefaultViewChangedEventArgs e)
	{
		SyncCalendars();
	}

	private void SyncCalendars()
	{
		RadCalendar2.FocusedDate = RadCalendar1.FocusedDate.AddMonths(1);
	}

	protected void RadCalendar1_SelectionChanged(object sender, SelectedDatesEventArgs e)
	{
		if (RadCalendar1.SelectedDates.Count > 0)
		{
			RadScheduler1.SelectedDate = RadCalendar1.SelectedDate;
			RadCalendar2.SelectedDate = RadCalendar1.SelectedDate;
		}
	}

	protected void RadCalendar2_SelectionChanged(object sender, SelectedDatesEventArgs e)
	{
		if (RadCalendar2.SelectedDates.Count > 0)
		{
			RadScheduler1.SelectedDate = RadCalendar2.SelectedDate;
			RadCalendar1.SelectedDate = RadCalendar2.SelectedDate;
		}
	}

	protected void RadScheduler1_AppointmentCreated(object sender, AppointmentCreatedEventArgs e)
	{
		if (e.Appointment.RecurrenceState == RecurrenceState.Master || e.Appointment.RecurrenceState == RecurrenceState.Occurrence)
		{
			Panel recurrenceStateDiv = new Panel();
			recurrenceStateDiv.CssClass = "rsAptRecurrence";
			e.Container.Controls.AddAt(0, recurrenceStateDiv);
		}
		if (e.Appointment.RecurrenceState == RecurrenceState.Exception)
		{
			Panel recurrenceStateDiv = new Panel();
			recurrenceStateDiv.CssClass = "rsAptRecurrenceException";
			e.Container.Controls.AddAt(0, recurrenceStateDiv);
		}
	}

	protected void RadScheduler1_AppointmentDataBound(object sender, SchedulerEventArgs e)
	{
		RadCalendarDay radCalendarDay = new RadCalendarDay(RadCalendar1);
		radCalendarDay.Date = e.Appointment.Start;
		radCalendarDay.ItemStyle.CssClass = "DayWithAppointments";
		RadCalendar1.SpecialDays.Add(radCalendarDay);
		RadCalendar2.SpecialDays.Add(radCalendarDay);

		e.Appointment.Visible = false;
	}

	protected void RadScheduler1_AppointmentDelete(object sender, SchedulerCancelEventArgs e)
	{
		RadCalendar1.SpecialDays.Clear();
		RadCalendar2.SpecialDays.Clear();
	}

	protected void RadScheduler1_AppointmentUpdate(object sender, AppointmentUpdateEventArgs e)
	{
		RadCalendar1.SpecialDays.Clear();
		RadCalendar2.SpecialDays.Clear();
	}

	protected void RadScheduler1_AppointmentInsert(object sender, SchedulerCancelEventArgs e)
	{
		if (e.Appointment.Resources.Count < 1)
			e.Appointment.Resources.Add(RadScheduler1.Resources.GetResource("Calendar", "1"));
	}

	protected void CheckBoxes_CheckedChanged(object sender, EventArgs e)
	{
		RadScheduler1.Rebind();
	}
}